@@ -19,6 +19,8 @@ fn main() {
         println!("cargo:rustc-link-lib=comdlg32");
         println!("cargo:rustc-link-lib=ole32");
         println!("cargo:rustc-link-lib=shell32");
-        println!("cargo:rustc-link-lib=shcore");
+        if !target.ends_with("pc-windows-gnu") {
+            println!("cargo:rustc-link-lib=shcore");
+        }
     }
 }
